@@ -2,7 +2,11 @@
 function(x, digits=4, ...)
 {
 cat(x$methodname, "\n")
+if(!is.null(x$df)){
 cat("Degree of freedom:", paste(signif(x$df, digits), collapse=", "), ", quantile:", paste(signif(x$quantile, digits), collapse=", "), "\n", sep="")
+}else{
+cat("Normal approximation, quantile:", paste(signif(x$quantile, digits), collapse=", "), "\n", sep="")
+}
 if(x$NSD)
 {
  print(cbind(estimate=x$estimate, x$conf.int) )
